"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Routes = exports.rootp = exports.root = void 0;
const Util_1 = __importDefault(require("../util/Util"));
exports.root = "https://api.ecoledirecte.com";
/**
 * Most likely used for teacher interactions
 */
exports.rootp = "https://apip.ecoledirecte.com";
exports.Routes = {
    //! LOGIN
    /**
     * Route for:
     * - POST /v3/login.awp
     */
    login() {
        return "/v3/login.awp";
    },
    //! TEACHER
    /**
     * Use with `root2`!
     *
     * Route for:
     * - POST *p/v3/niveauxListe.awp?verbe=get&v=4.14.7
     */
    teacherSchools() {
        return "/v3/niveauxListe.awp?verbe=get&v=4.14.7";
    },
    /**
     * Use with `root2`!
     *
     * Route for:
     * - POST *p/v3/classes/{classId}/eleves.awp?verbe=get&v=4.14.7
     */
    teacherStudents(classId) {
        return `/v3/classes/${classId}/eleves.awp?verbe=get&v=4.14.7`;
    },
    //! STUDENT
    /**
     * Route for:
     * - POST /v3/elevesDocuments.awp
     */
    studentDocuments(params) {
        const defaultParams = {
            archive: undefined,
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams("/v3/elevesDocuments.awp", nParams);
    },
    /**
     * Route for:
     * - POST /v3/telechargement.awp
     */
    downloadDocument(params) {
        const defaultParams = {
            verbe: "get",
            leTypeDeFichier: "",
            archive: false,
            anneeArchive: "",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams("/v3/telechargement.awp", nParams);
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/messages.awp
     */
    studentMailbox(studentId, params) {
        const defaultParams = {
            verbe: "getall",
            typeRecuperation: "received",
            orderBy: "date",
            order: "desc",
            page: 0,
            itemsPerPage: 0,
            onlyRead: "",
            query: "",
            idClasseur: 0,
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/eleves/${studentId}/messages.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/messages/{messageId}.awp
     */
    studentMessage(studentId, messageId, params) {
        const defaultParams = {
            verbe: "get",
            mode: "",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/eleves/${studentId}/messages/${messageId}.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/cahierdetexte.awp
     */
    studentHomework(studentId, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/Eleves/${studentId}/cahierdetexte.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/cahierdetexte/{date}.awp
     * @param date Must be of type YYYY-MM-DD
     */
    studentHomeworkDate(studentId, date, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/Eleves/${studentId}/cahierdetexte/${date}.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/notes.awp
     */
    studentGrades(studentId) {
        const params = {
            verbe: "get",
        };
        return Util_1.default.mergeParams(`/v3/eleves/${studentId}/notes.awp`, params);
    },
    /**
     * Route for:
     * - POST /v3/comptes/detail.awp
     */
    studentWallets() {
        return "/v3/comptes/detail.awp?verbe=get&v=4.14.3";
    },
    /**
     * Route for:
     * - POST /v3/eleves/{studentId}/timeline.awp
     */
    studentTimeline(studentId, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/eleves/${studentId}/timeline.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/{accountType}/{accountId}/timelineAccueilCommun.awp
     */
    commonTimeline(accountType, accountId, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/${accountType}/${accountId}/timelineAccueilCommun.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/${accountType}/${accountId}/emploidutemps.awp
     */
    timetable(accountType, accountId, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/${accountType}/${accountId}/emploidutemps.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/cloud/{accountType}/{accountId}.awp
     */
    cloudFolder(accountType, accountId, params) {
        const defaultParams = {
            verbe: "get",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams(`/v3/cloud/${accountType}/${accountId}.awp`, nParams);
    },
    /**
     * Route for:
     * - POST /v3/telechargement.awp?verbe=post&fichierId=string&leTypeDeFichier=CLOUD
     */
    downloadFile(params) {
        const defaultParams = {
            verbe: "post",
            leTypeDeFichier: "CLOUD",
        };
        const nParams = Util_1.default.mergeDefault(defaultParams, params);
        return Util_1.default.mergeParams("/v3/telechargement.awp", nParams);
    },
};
//# sourceMappingURL=routes.js.map